Struct Peripherals
Source pub struct Peripherals {Show 15 fields
pub pins: Pins,
pub uart0: UART0<'static>,
pub uart1: UART1<'static>,
pub i2c0: I2C0<'static>,
pub i2s0: I2S0<'static>,
pub spi1: SPI1<'static>,
pub spi2: SPI2<'static>,
pub adc1: ADC1<'static>,
pub adc2: ADC2<'static>,
pub can: CAN<'static>,
pub ledc: LEDC,
pub modem: Modem<'static>,
pub temp_sensor: TempSensor<'static>,
pub twdt: TWDT<'static>,
pub usb_serial: USB_SERIAL<'static>,
}
Safety
Care should be taken not to instantiate the Peripherals structure, if it is already instantiated and used elsewhere
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.